package com.tourism.webadmin.back.dto;

import com.tourism.common.core.validator.UpdateGroup;
import com.tourism.common.core.validator.ConstDictRef;
import com.tourism.webadmin.back.model.constant.Hotspot;
import com.tourism.webadmin.back.model.constant.Enable;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import jakarta.validation.constraints.*;

/**
 * 旅游项目管理Dto对象。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Schema(description = "TourismProjectDto对象")
@Data
public class TourismProjectDto {

    /**
     * 主键id。
     */
    @Schema(description = "主键id。", requiredMode = Schema.RequiredMode.REQUIRED)
    @NotNull(message = "数据验证失败，主键id不能为空！", groups = {UpdateGroup.class})
    private Long id;

    /**
     * 项目标题。
     * NOTE: 可支持等于操作符的列表数据过滤。
     */
    @Schema(description = "项目标题。可支持等于操作符的列表数据过滤。")
    private String projectTitle;

    /**
     * 项目简述。
     */
    @Schema(description = "项目简述。")
    private String remarks;

    /**
     * 是否热点。
     */
    @Schema(description = "是否热点，0非热点，1热点。")
    @ConstDictRef(constDictClass = Hotspot.class, message = "数据验证失败，是否热点为无效值！")
    private Integer isHotspot;

    /**
     * 标签。
     */
    @Schema(description = "标签。")
    private String projectLabel;

    /**
     * 显示顺序。
     */
    @Schema(description = "显示顺序。")
    private Integer showOrder;

    /**
     * 是否启用。
     */
    @Schema(description = "是否启用，0禁用，1启用。")
    @ConstDictRef(constDictClass = Enable.class, message = "数据验证失败，是否启用为无效值！")
    private Integer enable;

    /**
     * 所属分类。
     */
    @Schema(description = "所属分类。")
    private Long belongTab;

    /**
     * 出发地。
     */
    @Schema(description = "出发地。")
    private String startPlace;

    /**
     * 目的地。
     */
    @Schema(description = "目的地。")
    private String endPlace;

    /**
     * 总天数。
     */
    @Schema(description = "总天数。")
    private String countTimes;

    /**
     * 项目价格。
     */
    @Schema(description = "项目价格。")
    private String price;

    /**
     * 项目展示图片。
     */
    @Schema(description = "项目展示图片。")
    private String tourismUrl;

    /**
     * project_title LIKE搜索字符串。
     * NOTE: 可支持LIKE操作符的列表数据过滤。
     */
    @Schema(description = "LIKE模糊搜索字符串")
    private String searchString;
}
