package com.tourism.webadmin.back.model;

import com.baomidou.mybatisplus.annotation.*;
import com.tourism.webadmin.back.model.constant.Hotspot;
import com.tourism.webadmin.back.model.constant.Enable;
import com.tourism.common.core.util.MyCommonUtil;
import com.tourism.common.core.upload.UploadStoreTypeEnum;
import com.tourism.common.core.annotation.*;
import com.tourism.common.core.base.model.BaseModel;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Map;

/**
 * 劳务项目管理实体对象。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName(value = "tour_job_project")
public class JobProject extends BaseModel {

    /**
     * 主键id。
     */
    @TableId(value = "id")
    private Long id;

    /**
     * 出国劳务标题。
     */
    @TableField(value = "job_title")
    private String jobTitle;

    /**
     * 标签。
     */
    @TableField(value = "job_label")
    private String jobLabel;

    /**
     * 所属分类。
     */
    @TableField(value = "belong_tab")
    private Long belongTab;

    /**
     * 工作国家或地区。
     */
    @TableField(value = "job_area")
    private String jobArea;

    /**
     * 招聘人数。
     */
    @TableField(value = "job_people")
    private Integer jobPeople;

    /**
     * 职位月薪。
     */
    @TableField(value = "job_pay")
    private String jobPay;

    /**
     * 学历要求。
     */
    @TableField(value = "job_education")
    private String jobEducation;

    /**
     * 语言要求。
     */
    @TableField(value = "job_language")
    private String jobLanguage;

    /**
     * 合同期限。
     */
    @TableField(value = "job_contract")
    private String jobContract;

    /**
     * 截至日期。
     */
    @TableField(value = "job_deadline")
    private String jobDeadline;

    /**
     * 岗位要求。
     */
    @TableField(value = "job_require")
    private String jobRequire;

    /**
     * 福利待遇。
     */
    @TableField(value = "job_welfare")
    private String jobWelfare;

    /**
     * 工作时间。
     */
    @TableField(value = "job_time")
    private String jobTime;

    /**
     * 招聘岗位。
     */
    @TableField(value = "job_post")
    private String jobPost;

    /**
     * 项目优势。
     */
    @TableField(value = "job_advantage")
    private String jobAdvantage;

    /**
     * 劳务图片。
     */
    @UploadFlagColumn(storeType = UploadStoreTypeEnum.LOCAL_SYSTEM)
    @TableField(value = "job_url")
    private String jobUrl;

    /**
     * 是否热点。
     */
    @TableField(value = "is_hotspot")
    private Integer isHotspot;

    /**
     * 显示顺序。
     */
    @TableField(value = "show_order")
    private Integer showOrder;

    /**
     * 是否启用。
     */
    @TableField(value = "enable")
    private Integer enable;

    /**
     * 出国劳务简述。
     */
    @TableField(value = "remarks")
    private String remarks;

    /**
     * 逻辑删除标记字段(1: 正常 -1: 已删除)。
     */
    @TableLogic
    @TableField(value = "data_state")
    private Integer dataState;

    /**
     * job_title LIKE搜索字符串。
     */
    @TableField(exist = false)
    private String searchString;

    public void setSearchString(String searchString) {
        this.searchString = MyCommonUtil.replaceSqlWildcard(searchString);
    }

    @RelationOneToOne(
            masterIdField = "id",
            slaveModelClass = JobFile.class,
            slaveIdField = "associationTableId")
    @TableField(exist = false)
    private JobFile jobFile;

    @RelationOneToOne(
            masterIdField = "id",
            slaveModelClass = JobContent.class,
            slaveIdField = "associationId")
    @TableField(exist = false)
    private JobContent jobContent;

    @RelationDict(
            masterIdField = "belongTab",
            slaveModelClass = DirectoryInfo.class,
            slaveIdField = "id",
            slaveNameField = "menuName")
    @TableField(exist = false)
    private Map<String, Object> belongTabDictMap;

    @RelationConstDict(
            masterIdField = "isHotspot",
            constantDictClass = Hotspot.class)
    @TableField(exist = false)
    private Map<String, Object> isHotspotDictMap;

    @RelationConstDict(
            masterIdField = "enable",
            constantDictClass = Enable.class)
    @TableField(exist = false)
    private Map<String, Object> enableDictMap;
}
