package com.tourism.webadmin.back.vo;

import com.tourism.common.core.base.vo.BaseVo;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Map;

/**
 * 劳务项目管理VO视图对象。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Schema(description = "JobProjectVO视图对象")
@Data
@EqualsAndHashCode(callSuper = true)
public class JobProjectVo extends BaseVo {

    /**
     * 主键id。
     */
    @Schema(description = "主键id")
    private Long id;

    /**
     * 出国劳务标题。
     */
    @Schema(description = "出国劳务标题")
    private String jobTitle;

    /**
     * 标签。
     */
    @Schema(description = "标签")
    private String jobLabel;

    /**
     * 所属分类。
     */
    @Schema(description = "所属分类")
    private Long belongTab;

    /**
     * 工作国家或地区。
     */
    @Schema(description = "工作国家或地区")
    private String jobArea;

    /**
     * 招聘人数。
     */
    @Schema(description = "招聘人数")
    private Integer jobPeople;

    /**
     * 职位月薪。
     */
    @Schema(description = "职位月薪")
    private String jobPay;

    /**
     * 学历要求。
     */
    @Schema(description = "学历要求")
    private String jobEducation;

    /**
     * 语言要求。
     */
    @Schema(description = "语言要求")
    private String jobLanguage;

    /**
     * 合同期限。
     */
    @Schema(description = "合同期限")
    private String jobContract;

    /**
     * 截至日期。
     */
    @Schema(description = "截至日期")
    private String jobDeadline;

    /**
     * 岗位要求。
     */
    @Schema(description = "岗位要求")
    private String jobRequire;

    /**
     * 福利待遇。
     */
    @Schema(description = "福利待遇")
    private String jobWelfare;

    /**
     * 工作时间。
     */
    @Schema(description = "工作时间")
    private String jobTime;

    /**
     * 招聘岗位。
     */
    @Schema(description = "招聘岗位")
    private String jobPost;

    /**
     * 项目优势。
     */
    @Schema(description = "项目优势")
    private String jobAdvantage;

    /**
     * 劳务图片。
     */
    @Schema(description = "劳务图片")
    private String jobUrl;

    /**
     * 是否热点。
     */
    @Schema(description = "是否热点，0非热点，1热点")
    private Integer isHotspot;

    /**
     * 显示顺序。
     */
    @Schema(description = "显示顺序")
    private Integer showOrder;

    /**
     * 是否启用。
     */
    @Schema(description = "是否启用，0禁用，1启用")
    private Integer enable;

    /**
     * 出国劳务简述。
     */
    @Schema(description = "出国劳务简述")
    private String remarks;

    /**
     * id 的一对一关联数据对象，数据对应类型为JobFileVo。
     */
    @Schema(description = "id 的一对一关联数据对象，数据对应类型为JobFileVo")
    private Map<String, Object> jobFile;

    /**
     * id 的一对一关联数据对象，数据对应类型为JobContentVo。
     */
    @Schema(description = "id 的一对一关联数据对象，数据对应类型为JobContentVo")
    private Map<String, Object> jobContent;

    /**
     * belongTab 字典关联数据。
     */
    @Schema(description = "belongTab 字典关联数据")
    private Map<String, Object> belongTabDictMap;

    /**
     * isHotspot 常量字典关联数据。
     */
    @Schema(description = "isHotspot 常量字典关联数据")
    private Map<String, Object> isHotspotDictMap;

    /**
     * enable 常量字典关联数据。
     */
    @Schema(description = "enable 常量字典关联数据")
    private Map<String, Object> enableDictMap;
}
