package com.tourism.webadmin.back.vo;

import com.tourism.common.core.base.vo.BaseVo;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Map;

/**
 * 旅游项目管理VO视图对象。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Schema(description = "TourismProjectVO视图对象")
@Data
@EqualsAndHashCode(callSuper = true)
public class TourismProjectVo extends BaseVo {

    /**
     * 主键id。
     */
    @Schema(description = "主键id")
    private Long id;

    /**
     * 项目标题。
     */
    @Schema(description = "项目标题")
    private String projectTitle;

    /**
     * 项目简述。
     */
    @Schema(description = "项目简述")
    private String remarks;

    /**
     * 是否热点。
     */
    @Schema(description = "是否热点，0非热点，1热点")
    private Integer isHotspot;

    /**
     * 标签。
     */
    @Schema(description = "标签")
    private String projectLabel;

    /**
     * 显示顺序。
     */
    @Schema(description = "显示顺序")
    private Integer showOrder;

    /**
     * 是否启用。
     */
    @Schema(description = "是否启用，0禁用，1启用")
    private Integer enable;

    /**
     * 所属分类。
     */
    @Schema(description = "所属分类")
    private Long belongTab;

    /**
     * 出发地。
     */
    @Schema(description = "出发地")
    private String startPlace;

    /**
     * 目的地。
     */
    @Schema(description = "目的地")
    private String endPlace;

    /**
     * 总天数。
     */
    @Schema(description = "总天数")
    private String countTimes;

    /**
     * 项目价格。
     */
    @Schema(description = "项目价格")
    private String price;

    /**
     * 项目展示图片。
     */
    @Schema(description = "项目展示图片")
    private String tourismUrl;

    /**
     * id 的一对一关联数据对象，数据对应类型为TourismFileVo。
     */
    @Schema(description = "id 的一对一关联数据对象，数据对应类型为TourismFileVo")
    private Map<String, Object> tourismFile;

    /**
     * id 的一对一关联数据对象，数据对应类型为TourismContentVo。
     */
    @Schema(description = "id 的一对一关联数据对象，数据对应类型为TourismContentVo")
    private Map<String, Object> tourismContent;

    /**
     * belongTab 字典关联数据。
     */
    @Schema(description = "belongTab 字典关联数据")
    private Map<String, Object> belongTabDictMap;

    /**
     * isHotspot 常量字典关联数据。
     */
    @Schema(description = "isHotspot 常量字典关联数据")
    private Map<String, Object> isHotspotDictMap;

    /**
     * enable 常量字典关联数据。
     */
    @Schema(description = "enable 常量字典关联数据")
    private Map<String, Object> enableDictMap;
}
