package com.tourism.webadmin.upms.dto;

import com.tourism.common.core.validator.AddGroup;
import com.tourism.common.core.validator.UpdateGroup;
import com.tourism.common.core.validator.ConstDictRef;
import com.tourism.webadmin.upms.model.constant.SysUserType;
import com.tourism.webadmin.upms.model.constant.SysUserStatus;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import jakarta.validation.constraints.*;

/**
 * 用户管理Dto对象。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Schema(description = "SysUserWebDto对象")
@Data
public class SysUserWebDto {

    /**
     * 登录用户名。
     */
    @NotBlank(message = "数据验证失败，登录用户名不能为空！")
    private String loginName;

    /**
     * 用户密码。
     */
    @NotBlank(message = "数据验证失败，用户密码不能为空！", groups = {AddGroup.class})
    private String password;


    /**
     * 用户显示名称。
     */
    @NotBlank(message = "数据验证失败，用户显示名称不能为空！")
    private String showName;

    /**
     * 用户头像的Url。
     */
    @Schema(description = "用户头像的Url。")
    private String headImageUrl;

    /**
     * 用户邮箱。
     */
    @Schema(description = "用户邮箱。")
    private String email;

    /**
     * 用户手机。
     */
    @Schema(description = "用户手机。")
    @NotBlank(message = "数据验证失败，用户手机不能为空！")
    private String mobile;

    /**
     * 短信验证码。
     */
    @Schema(description = "短信验证码。")
    @NotBlank(message = "数据验证失败，短信验证码不能为空！")
    private String smsCode;
}
